require 'pry'
require 'rdig'
require '~/.pytheas/config.rb'
require 'pp'
require 'open-uri'
require 'net/http'

class Pytheas 
  include Cinch::Plugin
  listen_to :connect, method: :setup
  listen_to :channel, method: :on_channel
  listen_to :private, method: :on_privmsg

  def setup(*)
  end

  def on_privmsg(msg)
    if m = msg.message.match(/^\!s$/)
      reply_with_help(msg)
    end 
    if m = msg.message.match(/^\!s (.+)/)
      reply_with_search_results(msg, m)
    end 
  end

  def on_channel(msg)
    return if msg.message.start_with?("\u0001")

    if m = msg.message.match(/^\!s$/)
      reply_with_help(msg)
    end 
    if m = msg.message.match(/^\!s (.+)/)
      reply_with_search_results(msg, m, limit: 100)
    end 
  end

  private

  def reply_with_help(msg)
    msg.reply("Please specify some search terms.")
  end

  def reply_with_search_results(msg, m, limit: nil)
    options = {
      limit: limit,
      :highlight => { 
        :pre_tag => '*',
        :post_tag => '*',
        :ellipsis => '...',
        :excerpt_length => 70,
        :num_excerpts => 3 
      }
    }
    search_results = RDig.searcher.search(m[1], options)
    results = search_results[:list]
    if results.size > 0
      params = {'param1' => 'value1', 'pastebox' => format_results(results)}
      url = URI.parse('http://paste.deedbot.org')
      resp, data = Net::HTTP.post_form(url, params)
      full_results_url =  resp['location']
      msg.reply("#{results.size} results")
      results[0..1].each do |result|
        msg.reply(result[:url])
        msg.reply("\t\t\t" + result[:title])
        if result[:extract]
          result[:extract].each do |excerpt|
            msg.reply("\t\t\t" + excerpt)
          end
        end
      end 
      msg.reply("All results can be found at #{full_results_url}")
    else
      msg.reply("#{results.size} results")
    end
  end

  def format_results(results)
    formatted_string = ""
    results.each do |result|
      formatted_string << result[:url] + "\n"
      formatted_string << "\t" + result[:title] + "\n"
      if result[:extract]
        result[:extract].each do |excerpt|
          formatted_string << "\t\t" + excerpt + "\n"
        end
      end
    end
    formatted_string
  end
end

